//  $Id: config_sound.hpp 854 2006-11-06 14:10:45Z coz $
//
//  SuperTuxKart - a fun racing game with go-kart
//  Copyright (C) 2006 SuperTuxKart-Team
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#ifndef HEADER_CONFIGSOUND_H
#define HEADER_CONFIGSOUND_H

#include "base_gui.hpp"

class ConfigSound: public BaseGUI
{
public:
    ConfigSound();
    ~ConfigSound();

    void update(float dt);
    void select();

private:
    int m_music_menu_id;
    int m_sfx_menu_id;
};

#endif
